import { Application, ApplicationDocument, CreateApplicationRequest, PatchApplicationRequest, UploadDocumentRequest, VerifyDocumentRequest } from "../types/application";
import { UnitResponse, Include, UnitConfig, BaseListParams, BeneficialOwner } from "../types/common";
import { BaseResource } from "./baseResource";
export declare class Applications extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    list(params?: ApplicationListParams): Promise<UnitResponse<Application[]>>;
    create(request: CreateApplicationRequest): Promise<UnitResponse<Application> & Include<ApplicationDocument[] | BeneficialOwner[]>>;
    upload(request: UploadDocumentRequest): Promise<UnitResponse<ApplicationDocument>>;
    update(request: PatchApplicationRequest): Promise<UnitResponse<Application>>;
    get(applicationId: string): Promise<UnitResponse<Application> & Include<ApplicationDocument[]>>;
    listDocuments(applicationId: string): Promise<UnitResponse<ApplicationDocument[]>>;
    createDocument(applicationId: string): Promise<UnitResponse<ApplicationDocument>>;
    verifyDocument(request: VerifyDocumentRequest): Promise<UnitResponse<ApplicationDocument>>;
}
export interface ApplicationListParams extends BaseListParams {
    /**
     * Optional. Search term according to the Full-Text Search Rules.
     * default: empty
     */
    query?: string;
    /**
     * Optional. Filter applications by email address (case sensitive).
     * default: empty
     */
    email?: string;
    /**
     * Optional. Filter Applications by Tags.
     * default: empty
     */
    tags?: object;
    /**
     * Optional. sort=createdAt for ascending order or sort=-createdAt (leading minus sign) for descending order.
     * default: sort=-createdAt
     */
    sort?: string;
    /**
     * Optional. Filter Account by its status (Open, Frozen, or Closed). Usage example: filter[status][0]=Closed
     */
    status?: string[];
}
