"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseResource = void 0;
const axios_1 = __importDefault(require("axios"));
const types_1 = require("../types");
const MAX_REQUEST_SIZE = 20000000;
class BaseResource {
    constructor(token, resourcePath, config) {
        var _a;
        this.resourcePath = resourcePath;
        this.headers = {
            "Authorization": `Bearer ${token}`,
            "Content-Type": "application/vnd.api+json",
            ...((config === null || config === void 0 ? void 0 : config.sdkUserAgent) && { "User-Agent": "unit-node-sdk" })
        };
        this.axios = (_a = config === null || config === void 0 ? void 0 : config.axios) !== null && _a !== void 0 ? _a : axios_1.default;
    }
    async httpGet(path, config) {
        const conf = {
            headers: this.mergeHeaders(config === null || config === void 0 ? void 0 : config.headers),
            ...((config === null || config === void 0 ? void 0 : config.params) && { params: (config.params) }),
            ...((config === null || config === void 0 ? void 0 : config.responseEncoding) && { responseEncoding: config.responseEncoding }),
            ...((config === null || config === void 0 ? void 0 : config.responseType) && { responseType: config.responseType })
        };
        return await this.axios.get(this.resourcePath + path, conf)
            .then(r => r.data)
            .catch(error => { throw (0, types_1.extractUnitError)(error); });
    }
    async httpPatch(path, data, config) {
        const conf = {
            headers: this.mergeHeaders(config === null || config === void 0 ? void 0 : config.headers),
            maxBodyLength: MAX_REQUEST_SIZE,
            maxContentLength: MAX_REQUEST_SIZE,
            ...((config === null || config === void 0 ? void 0 : config.params) && { params: (config.params) })
        };
        const d = !data || (data && "data" in data) ? data : {
            data: {
                type: data.type,
                attributes: data.attributes
            }
        };
        return await this.axios.patch(this.resourcePath + path, d, conf)
            .then(r => r.data)
            .catch(error => { throw (0, types_1.extractUnitError)(error); });
    }
    async httpPost(path, data, config) {
        const conf = {
            headers: this.mergeHeaders(config === null || config === void 0 ? void 0 : config.headers),
            maxBodyLength: MAX_REQUEST_SIZE,
            maxContentLength: MAX_REQUEST_SIZE,
            ...((config === null || config === void 0 ? void 0 : config.params) && { params: (config.params) })
        };
        return await this.axios.post(this.resourcePath + path, data, conf)
            .then(r => r.data)
            .catch(error => { throw (0, types_1.extractUnitError)(error); });
    }
    async httpPostFullPath(path, data, config) {
        const conf = {
            headers: this.mergeHeaders(config === null || config === void 0 ? void 0 : config.headers),
            maxBodyLength: MAX_REQUEST_SIZE,
            maxContentLength: MAX_REQUEST_SIZE,
            ...((config === null || config === void 0 ? void 0 : config.params) && { params: (config.params) })
        };
        return await this.axios.post(path, data, conf)
            .then(r => r.data)
            .catch(error => { throw (0, types_1.extractUnitError)(error); });
    }
    async httpPut(path, data, config) {
        const conf = {
            headers: this.mergeHeaders(config === null || config === void 0 ? void 0 : config.headers),
            maxBodyLength: MAX_REQUEST_SIZE,
            maxContentLength: MAX_REQUEST_SIZE,
            ...((config === null || config === void 0 ? void 0 : config.params) && { params: (config.params) })
        };
        return await this.axios.put(this.resourcePath + path, data, conf)
            .then(r => r.data)
            .catch(error => { throw (0, types_1.extractUnitError)(error); });
    }
    async httpDelete(path, data) {
        const conf = {
            headers: this.headers,
            data
        };
        return await this.axios.delete(this.resourcePath + path, conf)
            .then(r => r.data)
            .catch(error => { throw (0, types_1.extractUnitError)(error); });
    }
    mergeHeaders(configHeaders) {
        return configHeaders ? { ...this.headers, ...configHeaders } : this.headers;
    }
}
exports.BaseResource = BaseResource;
