"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const unit_1 = require("../unit"); //CreateLinkedPaymentRequest
const testHelpers_1 = require("./testHelpers");
// import { createCounterpartyForTest } from "./counterparties.spec"
const dotenv_1 = __importDefault(require("dotenv"));
dotenv_1.default.config();
const unit = new unit_1.Unit(process.env.UNIT_TOKEN || "test", process.env.UNIT_API_URL || "test");
const paymentsId = [];
describe("Payments List", () => {
    test("Get Payments List", async () => {
        const res = await unit.payments.list();
        res.data.forEach(element => {
            expect(element.type).toContain("Payment");
            paymentsId.push(element.id);
        });
    });
});
describe("Get Payment Test", () => {
    test("get each payment", async () => {
        const paymentsList = (await unit.payments.list({ type: ["AchPayment", "BillPayment", "WirePayment"] })).data;
        paymentsList.forEach(async (p) => {
            const res = await unit.payments.get(p.id, "account");
            expect(res.data.type).toContain("Payment");
            const acc = res.included ? res.included[0] : undefined;
            if (acc)
                expect(acc.type).toContain("Account");
        });
    });
});
describe("Create BookPayment", () => {
    test("create bookpayment", async () => {
        const createDepositAccountRes = await (0, testHelpers_1.createIndividualAccount)(unit);
        const createAnotherDepositAccountRes = await (0, testHelpers_1.createIndividualAccount)(unit);
        const req = {
            "type": "bookPayment",
            "attributes": {
                "amount": 200,
                // "direction": "Credit",
                "description": "Book payment"
            },
            "relationships": {
                "account": {
                    "data": {
                        "type": "depositAccount",
                        "id": createDepositAccountRes.data.id
                    }
                },
                "counterpartyAccount": {
                    "data": {
                        "type": "depositAccount",
                        "id": createAnotherDepositAccountRes.data.id
                    }
                }
            }
        };
        const res = await unit.payments.create(req);
        expect(res.data.type === "bookPayment").toBeTruthy();
    });
});
// async function createPayment() : Promise<CreateLinkedPaymentRequest> {
//     const createCounterpartRes = await createCounterpartyForTest("22603")
//     return {
//             "type": "achPayment",
//             "attributes": {
//                 "amount": 200,
//                 "direction": "Debit",
//                 "description": "ACH PYMT"
//             },
//             "relationships": {
//                 "account": {
//                     "data": {
//                         "type": "depositAccount",
//                         "id": "27573"
//                     }
//                 },
//                 "counterparty": {
//                     "data": {
//                         "type": "counterparty",
//                         "id": createCounterpartRes.data.id
//                     }
//                 }
//             }
//     }
// }
// describe("Create LinkedPayment", () => {
//     test("create linked payment", async () => {
//
//
//         const req: CreateLinkedPaymentRequest = (await createPayment())
//
//         const createPaymentRes = await unit.payments.create(req)
//         const res = await unit.payments.get(createPaymentRes.data.id)
//         expect(res.data.type === "achPayment").toBeTruthy()
//     })
// })
//
// describe("Create and cancel LinkedPayment", () => {
//     test("create and cancel linked payment", async () => {
//
//
//         const req: CreateLinkedPaymentRequest = (await createPayment())
//
//         const createPaymentRes = await unit.payments.create(req)
//         const res = await unit.payments.cancel(createPaymentRes.data.id)
//         expect(res.data.type === "achPayment").toBeTruthy()
//     })
// })
